summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorVagrant Cascadian <vagrant@debian.org>2017-09-19 11:17:46 -0700
committerHolger Levsen <holger@layer-acht.org>2017-09-19 20:44:33 +0200
commit144c8a9088df7a75241e1d7186ba651cdc4f0354 (patch)
treeb54676e00cf1729b77aafb3887115b0ad0f74bbc
parenteae2b48d1fcd6ce16aadf248de1e7da03d3b671c (diff)
downloadjenkins.debian.net-144c8a9088df7a75241e1d7186ba651cdc4f0354.tar.xz
reproducible: Re-enable ff64a, adding two more armhf build jobs.
Signed-off-by: Holger Levsen <holger@layer-acht.org>
-rw-r--r--README3
-rwxr-xr-xbin/jenkins_node_definitions.sh1
-rwxr-xr-xbin/reproducible_build_service.sh10
-rwxr-xr-xbin/reproducible_node_health_check.sh2
-rwxr-xr-xdeploy_jdn1
-rw-r--r--job-cfg/reproducible.yaml3
6 files changed, 14 insertions, 6 deletions
diff --git a/README b/README
index 293e1a4a..c41749ab 100644
--- a/README
+++ b/README
@@ -143,8 +143,9 @@ Installation tests inside chroot environments.
** for 'amd64' we are using four virtual machines, profitbricks-build(1+5+11+15)-amd64, which have 15 or 16 cores and 48gb ram each. These nodes are sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Profitbricks].
** for 'i386' we are also using four virtual machines, profitbricks-build(2+6+12+16)-i386, which have 10 or 9 cores and 36gb ram each. pb2+12 run emulated AMD Opteron CPUs and pb6+16 Intel Xeon CPUs. These nodes are also sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Profitbricks].
** for 'arm64' we are using eight "moonshot" sleds, codethink-sled9-15-arm64, which have 8 cores and 64gb ram each. These nodes are sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Codethink].
-** To test 'armhf' we are using 28 small boards hosted by vagrant@d.o:
+** To test 'armhf' we are using 29 small boards hosted by vagrant@d.o:
*** six quad-cores (cbxi4a, cbxi4b, ff4a, jtx1a, jtx1b, jtx1c) with 4gb ram,
+*** one hexa-core (ff64a) with 2gb ram,
*** three octo-cores (odxu4, odxu4b and odxu4c) with 2gb ram,
*** twelve quad-cores (wbq0, cbxi4pro0, ff2a, ff2b, odu3a, opi2a, opi2b, opi2c, jtk1a, jtk1b, p64b and p64c) with 2gb ram,
*** two dual-core (bbx15 and cb3a) with 2gb ram and,
diff --git a/bin/jenkins_node_definitions.sh b/bin/jenkins_node_definitions.sh
index 85b566f1..9187e883 100755
--- a/bin/jenkins_node_definitions.sh
+++ b/bin/jenkins_node_definitions.sh
@@ -28,6 +28,7 @@ codethink-sled16-arm64.debian.net
ff2a-armhf-rb.debian.net
ff2b-armhf-rb.debian.net
ff4a-armhf-rb.debian.net
+ff64a-armhf-rb.debian.net
hb0-armhf-rb.debian.net
jtk1a-armhf-rb.debian.net
jtk1b-armhf-rb.debian.net
diff --git a/bin/reproducible_node_health_check.sh b/bin/reproducible_node_health_check.sh
index e24166e4..97a67dd6 100755
--- a/bin/reproducible_node_health_check.sh
+++ b/bin/reproducible_node_health_check.sh
@@ -145,7 +145,7 @@ if [ "$HOSTNAME" = "$MAINNODE" ] ; then
# and we dont know why and when that happens,
# so just report those zombies here.
#
- ZOMBIES=$(ls -1d /var/lib/jenkins/jobs/* | egrep 'reproducible_(builder_(amd64|i386|armhf|arm64)|setup_(pbuilder|schroot)_testing)|chroot-installation_wheezy|aptdpkg|ff64a|odc2a|stretch_install_education-thin-client-server|jessie_multiarch_versionskew|dpkg_stretch_find_trigger_cycles|sid_install_education-services|buster_install_education-services' || true)
+ ZOMBIES=$(ls -1d /var/lib/jenkins/jobs/* | egrep 'reproducible_(builder_(amd64|i386|armhf|arm64)|setup_(pbuilder|schroot)_testing)|chroot-installation_wheezy|aptdpkg|odc2a|stretch_install_education-thin-client-server|jessie_multiarch_versionskew|dpkg_stretch_find_trigger_cycles|sid_install_education-services|buster_install_education-services' || true)
if [ ! -z "$ZOMBIES" ] ; then
echo "Warning, rise of the jenkins job zombies has started again, these jobs should not exist:"
for z in $ZOMBIES ; do
diff --git a/deploy_jdn b/deploy_jdn
index 8998e79c..da71806a 100755
--- a/deploy_jdn
+++ b/deploy_jdn
@@ -59,6 +59,7 @@ cbxi4pro0-armhf-rb.debian.net
ff2a-armhf-rb.debian.net
ff2b-armhf-rb.debian.net
ff4a-armhf-rb.debian.net
+ff64a-armhf-rb.debian.net
hb0-armhf-rb.debian.net
jtk1a-armhf-rb.debian.net
jtk1b-armhf-rb.debian.net
diff --git a/job-cfg/reproducible.yaml b/job-cfg/reproducible.yaml
index 87a7ec4f..2f9076a4 100644
--- a/job-cfg/reproducible.yaml
+++ b/job-cfg/reproducible.yaml
@@ -290,6 +290,7 @@
- 'ff2a': { my_arch: 'armhf' }
- 'ff2b': { my_arch: 'armhf' }
- 'ff4a': { my_arch: 'armhf' }
+ - 'ff64a': { my_arch: 'armhf' }
- 'hb0': { my_arch: 'armhf' }
- 'jtk1a': { my_arch: 'armhf' }
- 'jtk1b': { my_arch: 'armhf' }
@@ -345,6 +346,7 @@
- 'ff2a': { my_arch: 'armhf' }
- 'ff2b': { my_arch: 'armhf' }
- 'ff4a': { my_arch: 'armhf' }
+ - 'ff64a': { my_arch: 'armhf' }
- 'hb0': { my_arch: 'armhf' }
- 'jtk1a': { my_arch: 'armhf' }
- 'jtk1b': { my_arch: 'armhf' }
@@ -421,6 +423,7 @@
- 'ff2a': { my_arch: 'armhf' }
- 'ff2b': { my_arch: 'armhf' }
- 'ff4a': { my_arch: 'armhf' }
+ - 'ff64a': { my_arch: 'armhf' }
- 'hb0': { my_arch: 'armhf' }
- 'jtk1a': { my_arch: 'armhf' }
- 'jtk1b': { my_arch: 'armhf' }
diff --git a/bin/reproducible_build_service.sh b/bin/reproducible_build_service.sh
index 28f8c7e5..e85cb651 100755
--- a/bin/reproducible_build_service.sh
+++ b/bin/reproducible_build_service.sh
@@ -116,7 +116,7 @@ choose_nodes() {
arm64_31) NODE1=codethink-sled14-arm64 NODE2=codethink-sled11-arm64 ;;
arm64_32) NODE1=codethink-sled13-arm64 NODE2=codethink-sled14-arm64 ;;
# to choose new armhf jobs:
# for i in hb0 rpi2b rpi2c wbd0 bpi0 cb3a bbx15 cbxi4pro0 ff2a ff2b jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b jtx1c; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
# 6 jobs for quad-cores with 4 gb ram
# 4 jobs for octo-cores with 2 gb ram
# 4 jobs for hexa-cores with 2 gb ram
@@ -171,7 +171,7 @@ choose_nodes() {
armhf_42) NODE1=cbxi4a-armhf-rb NODE2=rpi2c-armhf-rb ;;
armhf_43) NODE1=cbxi4b-armhf-rb NODE2=bbx15-armhf-rb ;;
armhf_44) NODE1=cbxi4b-armhf-rb NODE2=cb3a-armhf-rb ;;
- armhf_45) NODE1=cbxi4b-armhf-rb NODE2=hb0-armhf-rb ;;
+ armhf_45) NODE1=cbxi4b-armhf-rb NODE2=ff64a-armhf-rb ;;
armhf_46) NODE1=ff4a-armhf-rb NODE2=jtk1a-armhf-rb ;;
armhf_47) NODE1=ff4a-armhf-rb NODE2=wbd0-armhf-rb ;;
armhf_48) NODE1=ff4a-armhf-rb NODE2=jtx1c-armhf-rb ;;
@@ -183,7 +183,9 @@ choose_nodes() {
armhf_54) NODE1=jtx1c-armhf-rb NODE2=cbxi4a-armhf-rb ;;
armhf_55) NODE1=jtx1c-armhf-rb NODE2=odu3a-armhf-rb ;;
armhf_56) NODE1=jtk1a-armhf-rb NODE2=wbq0-armhf-rb ;;
- armhf_57) NODE1=jtk1a-armhf-rb NODE2=bpi0-armhf-rb ;;
+ armhf_57) NODE1=jtk1a-armhf-rb NODE2=ff64a-armhf-rb ;;
+ armhf_58) NODE1=ff64a-armhf-rb NODE2=hb0-armhf-rb ;;
+ armhf_59) NODE1=ff64a-armhf-rb NODE2=bpi0-armhf-rb ;;
*) NODE1=undefined
;;
esac
@@ -198,7 +200,7 @@ startup_workers() {
amd64) MAX=40 ;;
i386) MAX=24 ;;
arm64) MAX=32 ;;
- armhf) MAX=57 ;;
+ armhf) MAX=59 ;;
*) ;;
esac
#
@@ -116,7 +116,7 @@ choose_nodes() {
arm64_32) NODE1=codethink-sled13-arm64 NODE2=codethink-sled14-arm64 ;;
# to choose new armhf jobs:
- # for i in hb0 rpi2b rpi2c wbd0 bpi0 cb3a bbx15 cbxi4pro0 ff2a ff2b jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b jtx1c; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
+ # for i in hb0 rpi2b rpi2c wbd0 bpi0 cb3a bbx15 cbxi4pro0 ff2a ff2b ff64a jtk1a jtk1b odxu4 odxu4b odxu4c odu3a opi2a opi2b opi2c p64b p64c wbq0 cbxi4a cbxi4b ff4a jtx1a jtx1b jtx1c; do echo "$i: " ; grep NODE1 bin/reproducible_build_service.sh|grep armhf|grep $i-armhf ; done
# 6 jobs for quad-cores with 4 gb ram
# 4 jobs for octo-cores with 2 gb ram